@@ -3,30 +3,29 @@
 from __future__ import absolute_import, unicode_literals
 
 import random
+import re
 import socket
-import warnings
-import zlib
 from collections import OrderedDict
 
 from django.conf import settings
 from django.core.cache.backends.base import DEFAULT_TIMEOUT, get_key_func
 from django.core.exceptions import ImproperlyConfigured
+from django.utils import six
 from django.utils.encoding import smart_text
+from redis.exceptions import ConnectionError, ResponseError, TimeoutError
 
-from redis.exceptions import ConnectionError
-from redis.exceptions import ResponseError
-
-# Compatibility with redis-py 2.10.x+
-
-try:
-    from redis.exceptions import TimeoutError, ResponseError
-    _main_exceptions = (TimeoutError, ResponseError, ConnectionError, socket.timeout)
-except ImportError:
-    _main_exceptions = (ConnectionError, socket.timeout)
-
-from ..util import CacheKey, load_class, integer_types
-from ..exceptions import ConnectionInterrupted, CompressorError
 from .. import pool
+from ..exceptions import CompressorError, ConnectionInterrupted
+from ..util import CacheKey, load_class
+
+_main_exceptions = (TimeoutError, ResponseError, ConnectionError, socket.timeout)
+
+
+special_re = re.compile('([*?[])')
+
+
+def glob_escape(s):
+    return special_re.sub(r'[\1]', s)
 
 
 class DefaultClient(object):
@@ -55,7 +54,7 @@ class DefaultClient(object):
         compressor_cls = load_class(compressor_path)
 
         self._serializer = serializer_cls(options=self._options)
-        self._compressor = compressor_cls(options=self._options);
+        self._compressor = compressor_cls(options=self._options)
 
         self.connection_factory = pool.get_connection_factory(options=self._options)
 
@@ -114,10 +113,6 @@ class DefaultClient(object):
         nkey = self.make_key(key, version=version)
         nvalue = self.encode(value)
 
-        if timeout is True:
-            warnings.warn("Using True as timeout value, is now deprecated.", DeprecationWarning)
-            timeout = self._backend.default_timeout
-
         if timeout == DEFAULT_TIMEOUT:
             timeout = self._backend.default_timeout
 
@@ -129,15 +124,15 @@ class DefaultClient(object):
                     client, index = self.get_client(write=True, tried=tried, show_index=True)
 
                 if timeout is not None:
-                    if timeout > 0:
-                        # Convert to milliseconds
-                        timeout = int(timeout * 1000)
-                    elif timeout <= 0:
+                    # Convert to milliseconds
+                    timeout = int(timeout * 1000)
+
+                    if timeout <= 0:
                         if nx:
                             # Using negative timeouts when nx is True should
                             # not expire (in our case delete) the value if it exists.
                             # Obviously expire not existent value is noop.
-                            timeout = None
+                            return not self.has_key(key, version=version, client=client)
                         else:
                             # redis doesn't support negative timeouts in ex flags
                             # so it seems that it's better to just delete the key
@@ -261,7 +256,7 @@ class DefaultClient(object):
         if client is None:
             client = self.get_client(write=True)
 
-        pattern = self.make_key(pattern, version=version, prefix=prefix)
+        pattern = self.make_pattern(pattern, version=version, prefix=prefix)
 
         kwargs = {'match': pattern, }
         if itersize:
@@ -303,11 +298,7 @@ class DefaultClient(object):
             client = self.get_client(write=True)
 
         try:
-            count = 0
-            for key in client.scan_iter("*"):
-                client.delete(key)
-                count += 1
-            return count
+            client.flushdb()
         except _main_exceptions as e:
             raise ConnectionInterrupted(connection=client, parent=e)
 
@@ -331,7 +322,7 @@ class DefaultClient(object):
         Encode the given value.
         """
 
-        if isinstance(value, bool) or not isinstance(value, integer_types):
+        if isinstance(value, bool) or not isinstance(value, six.integer_types):
             value = self._serializer.dumps(value)
             value = self._compressor.compress(value)
             return value
@@ -351,15 +342,16 @@ class DefaultClient(object):
 
         recovered_data = OrderedDict()
 
-        new_keys = [self.make_key(k, version=version) for k in keys]
-        map_keys = dict(zip(new_keys, keys))
+        map_keys = OrderedDict(
+            (self.make_key(k, version=version), k) for k in keys
+        )
 
         try:
-            results = client.mget(*new_keys)
+            results = client.mget(*map_keys)
         except _main_exceptions as e:
             raise ConnectionInterrupted(connection=client, parent=e)
 
-        for key, value in zip(new_keys, results):
+        for key, value in zip(map_keys, results):
             if value is None:
                 continue
             recovered_data[map_keys[key]] = self.decode(value)
@@ -384,7 +376,7 @@ class DefaultClient(object):
         except _main_exceptions as e:
             raise ConnectionInterrupted(connection=client, parent=e)
 
-    def _incr(self, key, delta=1, version=None, client=None):
+    def _incr(self, key, delta=1, version=None, client=None, ignore_key_check=False):
         if client is None:
             client = self.get_client(write=True)
 
@@ -395,12 +387,17 @@ class DefaultClient(object):
                 # if key expired after exists check, then we get
                 # key with wrong value and ttl -1.
                 # use lua script for atomicity
-                lua = """
-                local exists = redis.call('EXISTS', KEYS[1])
-                if (exists == 1) then
+                if not ignore_key_check:
+                    lua = """
+                    local exists = redis.call('EXISTS', KEYS[1])
+                    if (exists == 1) then
+                        return redis.call('INCRBY', KEYS[1], ARGV[1])
+                    else return false end
+                    """
+                else:
+                    lua = """
                     return redis.call('INCRBY', KEYS[1], ARGV[1])
-                else return false end
-                """
+                    """
                 value = client.eval(lua, 1, key, delta)
                 if value is None:
                     raise ValueError("Key '%s' not found" % key)
@@ -425,12 +422,13 @@ class DefaultClient(object):
 
         return value
 
-    def incr(self, key, delta=1, version=None, client=None):
+    def incr(self, key, delta=1, version=None, client=None, ignore_key_check=False):
         """
         Add delta to value in the cache. If the key does not exist, raise a
-        ValueError exception.
+        ValueError exception. if ignore_key_check=True then the key will be
+        created and set to the delta value by default.
         """
-        return self._incr(key=key, delta=delta, version=version, client=client)
+        return self._incr(key=key, delta=delta, version=version, client=client, ignore_key_check=ignore_key_check)
 
     def decr(self, key, delta=1, version=None, client=None):
         """
@@ -487,7 +485,7 @@ class DefaultClient(object):
         if client is None:
             client = self.get_client(write=False)
 
-        pattern = self.make_key(search, version=version)
+        pattern = self.make_pattern(search, version=version)
         for item in client.scan_iter(match=pattern, count=itersize):
             item = smart_text(item)
             yield self.reverse_key(item)
@@ -503,7 +501,7 @@ class DefaultClient(object):
         if client is None:
             client = self.get_client(write=False)
 
-        pattern = self.make_key(search, version=version)
+        pattern = self.make_pattern(search, version=version)
         try:
             encoding_map = [smart_text(k) for k in client.keys(pattern)]
             return [self.reverse_key(k) for k in encoding_map]
@@ -522,8 +520,23 @@ class DefaultClient(object):
 
         return CacheKey(self._backend.key_func(key, prefix, version))
 
+    def make_pattern(self, pattern, version=None, prefix=None):
+        if isinstance(pattern, CacheKey):
+            return pattern
+
+        if prefix is None:
+            prefix = self._backend.key_prefix
+        prefix = glob_escape(prefix)
+
+        if version is None:
+            version = self._backend.version
+        version = glob_escape(str(version))
+
+        return CacheKey(self._backend.key_func(pattern, prefix, version))
+
     def close(self, **kwargs):
         if getattr(settings, "DJANGO_REDIS_CLOSE_CONNECTION", False):
-            for c in self.client.connection_pool._available_connections:
-                c.disconnect()
-            del self._client
+            for i in range(len(self._clients)):
+                for c in self._clients[i].connection_pool._available_connections:
+                    c.disconnect()
+                self._clients[i] = None
