@@ -5,23 +5,13 @@ import socket
 import time
 from collections import OrderedDict
 
-from redis.exceptions import ConnectionError
-
 from django.conf import settings
+from redis.exceptions import ConnectionError, ResponseError, TimeoutError
 
-from .default import DEFAULT_TIMEOUT, DefaultClient
 from ..exceptions import ConnectionInterrupted
+from .default import DEFAULT_TIMEOUT, DefaultClient
 
-from redis.exceptions import ConnectionError
-from redis.exceptions import ResponseError
-
-# Compatibility with redis-py 2.10.x+
-
-try:
-    from redis.exceptions import TimeoutError, ResponseError
-    _main_exceptions = (TimeoutError, ResponseError, ConnectionError, socket.timeout)
-except ImportError:
-    _main_exceptions = (ConnectionError, socket.timeout)
+_main_exceptions = (ConnectionError, ResponseError, TimeoutError, socket.timeout)
 
 
 class Marker(object):
@@ -51,8 +41,7 @@ class HerdClient(DefaultClient):
         super(HerdClient, self).__init__(*args, **kwargs)
 
     def _pack(self, value, timeout):
-        herd_timeout = ((timeout or self._backend.default_timeout)
-                        + int(time.time()))
+        herd_timeout = (timeout or self._backend.default_timeout) + int(time.time())
         return (self._marker, value, herd_timeout)
 
     def _unpack(self, value):
