@@ -1,10 +1,4 @@
-import re
-import warnings
-
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
-
-from redis import StrictRedis
 from redis.connection import DefaultParser
 
 from . import util
@@ -13,67 +7,53 @@ from . import util
 class ConnectionFactory(object):
 
     # Store connection pool by cache backend options.
-    # _pools is a process-global, as
-    # otherwise _pools is cleared every time ConnectionFactory is instiated,
-    # as Django creates new cache client (DefaultClient) instance for every request.
-    _pools = {}
+    #
+    # _pools is a process-global, as otherwise _pools is cleared every time
+    # ConnectionFactory is instiated, as Django creates new cache client
+    # (DefaultClient) instance for every request.
 
-    oldparams_rx = re.compile("^(?:[^:]+:\d{1,4}:\d+|unix:[\w/\-\.]+:\d+)$", flags=re.I)
+    _pools = {}
 
     def __init__(self, options):
         pool_cls_path = options.get("CONNECTION_POOL_CLASS",
                                     "redis.connection.ConnectionPool")
         self.pool_cls = util.load_class(pool_cls_path)
         self.pool_cls_kwargs = options.get("CONNECTION_POOL_KWARGS", {})
+
+        redis_client_cls_path = options.get("REDIS_CLIENT_CLASS",
+                                            "redis.client.StrictRedis")
+        self.redis_client_cls = util.load_class(redis_client_cls_path)
+        self.redis_client_cls_kwargs = options.get("REDIS_CLIENT_KWARGS", {})
+
         self.options = options
 
-    def adapt_old_url_format(self, url):
-        warnings.warn("Using deprecated connection string format.", DeprecationWarning)
-
-        password = self.options.get("PASSWORD", None)
-        try:
-            host, port, db = url.split(":")
-            port = port if host == "unix" else int(port)
-            db = int(db)
-
-            if host == "unix":
-                if password:
-                    url = "unix://:{password}@{port}?db={db}"
-                else:
-                    url = "unix://{port}?db={db}"
-            else:
-                if password:
-                    url = "redis://:{password}@{host}:{port}?db={db}"
-                else:
-                    url = "redis://{host}:{port}?db={db}"
-
-            return url.format(password=password,
-                              host=host,
-                              port=port,
-                              db=db)
-
-        except (ValueError, TypeError):
-            raise ImproperlyConfigured("Incorrect format '%s'" % (url))
-
     def make_connection_params(self, url):
         """
         Given a main connection parameters, build a complete
         dict of connection parameters.
         """
-        if self.oldparams_rx.match(url):
-            url = self.adapt_old_url_format(url)
 
         kwargs = {
             "url": url,
             "parser_class": self.get_parser_cls(),
         }
 
+        password = self.options.get("PASSWORD", None)
+        if password:
+            kwargs["password"] = password
+
         socket_timeout = self.options.get("SOCKET_TIMEOUT", None)
         if socket_timeout:
             assert isinstance(socket_timeout, (int, float)), \
                 "Socket timeout should be float or integer"
             kwargs["socket_timeout"] = socket_timeout
 
+        socket_connect_timeout = self.options.get("SOCKET_CONNECT_TIMEOUT", None)
+        if socket_connect_timeout:
+            assert isinstance(socket_connect_timeout, (int, float)), \
+                "Socket connect timeout should be float or integer"
+            kwargs["socket_connect_timeout"] = socket_connect_timeout
+
         return kwargs
 
     def connect(self, url):
@@ -94,7 +74,7 @@ class ConnectionFactory(object):
         for create new connection.
         """
         pool = self.get_or_create_connection_pool(params)
-        return StrictRedis(connection_pool=pool)
+        return self.redis_client_cls(connection_pool=pool, **self.redis_client_cls_kwargs)
 
     def get_parser_cls(self):
         cls = self.options.get("PARSER_CLASS", None)
@@ -125,7 +105,13 @@ class ConnectionFactory(object):
         """
         cp_params = dict(params)
         cp_params.update(self.pool_cls_kwargs)
-        return self.pool_cls.from_url(**cp_params)
+        pool = self.pool_cls.from_url(**cp_params)
+
+        if pool.connection_kwargs.get("password", None) is None:
+            pool.connection_kwargs["password"] = params.get("password", None)
+            pool.reset()
+
+        return pool
 
 
 def get_connection_factory(path=None, options=None):
