@@ -4,15 +4,14 @@ from __future__ import absolute_import, unicode_literals
 
 import json
 
-from django.core.exceptions import ImproperlyConfigured
-from django.utils.encoding import force_bytes, force_text
+from django.core.serializers.json import DjangoJSONEncoder
 
 from .base import BaseSerializer
 
 
 class JSONSerializer(BaseSerializer):
     def dumps(self, value):
-        return force_bytes(json.dumps(value))
+        return json.dumps(value, cls=DjangoJSONEncoder).encode()
 
     def loads(self, value):
-        return json.loads(force_text(value))
+        return json.loads(value.decode())
