@@ -3,9 +3,8 @@
 import os
 import sys
 
+sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_sqlite_usock")
-sys.path.insert(0, 'tests')
-
 
 if __name__ == "__main__":
     from django.core.management import execute_from_command_line
