@@ -1,16 +1,4 @@
-DATABASES = {
-    "default": {
-        "ENGINE": "django.db.backends.sqlite3"
-    },
-}
-
 SECRET_KEY = "django_tests_secret_key"
-TIME_ZONE = "America/Chicago"
-LANGUAGE_CODE = "en-us"
-ADMIN_MEDIA_PREFIX = "/static/admin/"
-STATICFILES_DIRS = ()
-
-MIDDLEWARE_CLASSES = []
 
 CACHES = {
     "default": {
@@ -39,7 +27,7 @@ CACHES = {
     },
     "with_prefix": {
         "BACKEND": "django_redis.cache.RedisCache",
-        "LOCATION": "127.0.0.1:6379:1",
+        "LOCATION": "redis://127.0.0.1:6379?db=1",
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
         },
@@ -49,6 +37,4 @@ CACHES = {
 
 INSTALLED_APPS = (
     "django.contrib.sessions",
-    "redis_backend_testapp",
-    "hashring_test",
 )
